package swifttest
import "github.com/docker/distribution/Godeps/_workspace/src/github.com/ncw/swift/swifttest"
This implements a very basic Swift server Everything is stored in memory
This comes from the https://github.com/mitchellh/goamz and was adapted for Swift
Index ¶
Constants ¶
const ( DEBUG = false TEST_ACCOUNT = "swifttest" )
Types ¶
type Folder ¶
The Folder type represents a container stored in an account
type Key ¶
type Key struct {
Key string `json:"name"`
LastModified string `json:"last_modified"`
Size int64 `json:"bytes"`
// ETag gives the hex-encoded MD5 sum of the contents,
// surrounded with double-quotes.
ETag string `json:"hash"`
ContentType string `json:"content_type"`
}
The Key type represents an item stored in an container.
type Subdir ¶
type Subdir struct {
Subdir string `json:"subdir"`
}
type SwiftServer ¶
type SwiftServer struct {
Listener net.Listener
AuthURL string
URL string
Accounts map[string]*account
Sessions map[string]*session
// contains filtered or unexported fields
}
func NewSwiftServer ¶
func NewSwiftServer(address string) (*SwiftServer, error)
func (*SwiftServer) Close ¶
func (srv *SwiftServer) Close()
Source Files ¶
- Version
- v2.3.0-rc.1+incompatible
- Published
- Jan 21, 2016
- Platform
- linux/amd64
- Imports
- 24 packages
- Last checked
- 5 seconds ago –
Tools for package owners.