package container
import "github.com/docker/distribution/Godeps/_workspace/src/google.golang.org/cloud/container"
Package container contains a Google Container Engine client.
For more information about the API, see https://cloud.google.com/container-engine/docs
Index ¶
- Variables
- func DeleteCluster(ctx context.Context, zone, name string) error
- type Op
- func Operation(ctx context.Context, zone, name string) (*Op, error)
- func Operations(ctx context.Context, zone string) ([]*Op, error)
- type Resource
- func Cluster(ctx context.Context, zone, name string) (*Resource, error)
- func Clusters(ctx context.Context, zone string) ([]*Resource, error)
- func CreateCluster(ctx context.Context, zone string, resource *Resource) (*Resource, error)
- type Status
- type Type
Variables ¶
var ( Done = Status("done") Pending = Status("pending") Running = Status("running") Error = Status("error") Provisioning = Status("provisioning") Stopping = Status("stopping") )
Functions ¶
func DeleteCluster ¶
DeleteCluster deletes a cluster.
Types ¶
type Op ¶
type Op struct {
// Name is the name of the operation.
Name string
// Zone is the Google Compute Engine zone.
Zone string
// This field is ignored. It was removed from the underlying container API in v1.
TargetURL string
// Type is the operation type. It could be either be TypeCreate or TypeDelete.
Type Type
// Status is the current status of this operation. It could be either
// OpDone or OpPending.
Status Status
}
Op represents a Google Container Engine API operation.
func Operation ¶
Operation returns an operation.
func Operations ¶
Operations returns a list of operations from the specified zone. If no zone is specified, it looks up for all of the operations that are running under the user's project.
type Resource ¶
type Resource struct {
// Name is the name of this cluster. The name must be unique
// within this project and zone, and can be up to 40 characters.
Name string
// Description is the description of the cluster. Optional.
Description string
// Zone is the Google Compute Engine zone in which the cluster resides.
Zone string
// Status is the current status of the cluster. It could either be
// StatusError, StatusProvisioning, StatusRunning or StatusStopping.
Status Status
// Num is the number of the nodes in this cluster resource.
Num int64
// APIVersion is the version of the Kubernetes master and kubelets running
// in this cluster. Allowed value is 0.4.2, or leave blank to
// pick up the latest stable release.
APIVersion string
// Endpoint is the IP address of this cluster's Kubernetes master.
// The endpoint can be accessed at https://username:password@endpoint/.
// See Username and Password fields for the username and password information.
Endpoint string
// Username is the username to use when accessing the Kubernetes master endpoint.
Username string
// Password is the password to use when accessing the Kubernetes master endpoint.
Password string
// ContainerIPv4CIDR is the IP addresses of the container pods in
// this cluster, in CIDR notation (e.g. 1.2.3.4/29).
ContainerIPv4CIDR string
// ServicesIPv4CIDR is the IP addresses of the Kubernetes services in this
// cluster, in CIDR notation (e.g. 1.2.3.4/29). Service addresses are
// always in the 10.0.0.0/16 range.
ServicesIPv4CIDR string
// MachineType is a Google Compute Engine machine type (e.g. n1-standard-1).
// If none set, the default type is used while creating a new cluster.
MachineType string
// This field is ignored. It was removed from the underlying container API in v1.
SourceImage string
// Created is the creation time of this cluster.
Created time.Time
}
Resource is a Google Container Engine cluster resource.
func Cluster ¶
Cluster returns metadata about the specified cluster.
func Clusters ¶
Clusters returns a list of cluster resources from the specified zone. If no zone is specified, it returns all clusters under the user project.
func CreateCluster ¶
CreateCluster creates a new cluster with the provided metadata in the specified zone.
type Status ¶
type Status string
type Type ¶
type Type string
Source Files ¶
- Version
- v2.3.1-rc.0+incompatible
- Published
- Feb 23, 2016
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 7 minutes ago –
Tools for package owners.